@@ -1,4 +1,4 @@
 from .version import __version__
 from .tasks import SyncEntitiesTask
-from .models import EntityModelMixin, Entity, BaseEntityModel, EntityModelManager
+from .models import EntityModelMixin, Entity, BaseEntityModel, EntityModelManager, EntityRelationship
 from .sync import sync_entities, turn_on_syncing, turn_off_syncing
